# ifndef yyHomeTraverse
# define yyHomeTraverse

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 15 "HomeTraverse.puma" */


# include "VarDescriptor.h"

typedef tTree UserFunction1 ();



extern void (* HomeTraverse_Exit) ARGS ((void));

extern tTree HomeReplaceAST ARGS ((tTree t, pvar home, UserFunction1 visit));

extern void BeginHomeTraverse ARGS ((void));
extern void CloseHomeTraverse ARGS ((void));

# endif
